@@ -25,6 +25,10 @@
 
 ;;; Code:
 
+(eval-when-compile
+  ;; For `with-slots'.
+  (require 'eieio))
+
 ;;; USA
 
 (defvar ebdb-i18n-usa-states
@@ -89,6 +93,31 @@
     ("Wyoming" . "WY"))
   "All the states in the US, for use with completion.")
 
+(cl-defmethod ebdb-parse-i18n ((_class (subclass ebdb-field-phone))
+			       (str string)
+			       (_cc (eql 1))
+			       &optional slots)
+  "Parse a US phone number.
+Uses first three digits as the area code, next seven as the
+number, and any remaining as an extension."
+  (let ((numstr (replace-regexp-in-string "[^[:digit:]]+" "" str))
+	ext)
+    (setq slots
+	  (plist-put
+	   (plist-put
+	    slots :area-code
+	    (string-to-number (substring numstr 0 3)))
+	   :number (substring numstr 3 10)))
+    (condition-case nil
+	(setq slots (plist-put
+		     slots
+		     :extension
+		     (when (and (setq ext (substring numstr 10))
+				(null (string-empty-p ext)))
+		       (string-to-number ext))))
+      (args-out-of-range nil))
+    slots))
+
 (cl-defmethod ebdb-string-i18n ((phone ebdb-field-phone)
 				(_cc (eql 1)))
   (with-slots (area-code number extension) phone
@@ -107,7 +136,7 @@
 	   slots :region
 	   (cdr (assoc-string
 		 (ebdb-read-string
-		  "State: "
+		  "State"
 		  (when obj (ebdb-address-region obj))
 		  ebdb-i18n-usa-states t)
 		 ebdb-i18n-usa-states)))))
@@ -133,7 +162,7 @@
 	(setq slots (plist-put slots :locality (match-string 1))))
       (setq slots (plist-put slots :streets
 			     (split-string (buffer-substring (point-min) (point))
-					   "[,\n]" t))))
+					   "[,\n]" t "[[:blank:]]"))))
     slots))
 
 ;;; France
@@ -201,7 +230,7 @@
 	   slots :region
 	   (cdr (assoc-string
 		 (ebdb-read-string
-		  "State: "
+		  "State"
 		  (when obj (ebdb-address-region obj))
 		  ebdb-i18n-india-states t)
 		 ebdb-i18n-india-states)))))
