@@ -1,6 +1,6 @@
 ;;; ebdb-i18n.el --- Internationalization support for EBDB  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2016-2018  Free Software Foundation, Inc.
+;; Copyright (C) 2016-2020  Free Software Foundation, Inc.
 
 ;; Author: Eric Abrahamsen <eric@ericabrahamsen.net>
 
@@ -723,12 +723,11 @@ for their symbol representations."
 		  (cdr-safe (assoc-string
 			     (match-string 0 str)
 			     (ebdb-i18n-countries)))))))
-    (or (and cc
-	     (symbolp cc)
-	     (condition-case nil
-		 (ebdb-parse-i18n class str cc slots)
-	       (cl-no-method nil)))
-	(signal 'ebdb-unparseable (list str)))))
+    (when (and cc (symbolp cc))
+      (condition-case nil
+	  (setq slots (ebdb-parse-i18n class str cc slots))
+	(cl-no-method nil)))
+    (cl-call-next-method class str slots)))
 
 (cl-defmethod ebdb-read :extra "i18n" ((class (subclass ebdb-field-phone))
 				       &optional slots obj)
@@ -783,17 +782,19 @@ for their symbol representations."
 (cl-defmethod ebdb-parse :extra "i18n" ((class (subclass ebdb-field-phone))
 					(str string)
 					&optional slots)
-  (let ((cc (or (plist-get slots :country-code)
-		(and (string-match "\\`(?\\+(?\\([0-9]\\{1,3\\}\\))?[ \t]+" str)
-		     (string-to-number (match-string 1 str))))))
-    (or (and cc
-	     (condition-case nil
-		 (ebdb-parse-i18n
-		  class
-		  (replace-match "" nil nil str 0)
-		  cc (plist-put slots :country-code cc))
-	       (cl-no-method nil)))
-	(cl-call-next-method))))
+  (let* ((cc-reg "\\`(?\\+(?\\([0-9]\\{1,3\\}\\))?[ \t]+")
+	 (cc (or (plist-get slots :country-code)
+		 (and (string-match cc-reg str)
+		      (string-to-number (match-string 1 str))))))
+    (when cc
+      (condition-case nil
+	  (setq slots
+		(ebdb-parse-i18n
+		 class
+		 (replace-regexp-in-string cc-reg "" str)
+		 cc (plist-put slots :country-code cc)))
+	(cl-no-method nil)))
+    (cl-call-next-method class str slots)))
 
 ;; We don't need to override the `ebdb-read' method for names.  It
 ;; only matters what script the name is in if the user has set
@@ -806,13 +807,13 @@ for their symbol representations."
   ;; user has entered.
   (let ((script (unless (string-empty-p string)
 		  (aref char-script-table (aref string 0)))))
-    (or (and script
-	     (null (memq script ebdb-i18n-ignorable-scripts))
-	     (condition-case nil
-		 (ebdb-parse-i18n class string script slots)
-	       (cl-no-method
-		nil)))
-	(cl-call-next-method))))
+    (when (and script
+	       (null (memq script ebdb-i18n-ignorable-scripts)))
+      (condition-case nil
+	  (setq slots (ebdb-parse-i18n class string script slots))
+	(cl-no-method
+	 nil)))
+    (cl-call-next-method class string slots)))
 
 (cl-defmethod ebdb-string :extra "i18n" ((name ebdb-field-name-complex))
   (let* ((str (cl-call-next-method name))
