@@ -1,6 +1,6 @@
 ;;; ebdb-rmail.el --- EBDB interface to Rmail        -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2016-2018  Free Software Foundation, Inc.
+;; Copyright (C) 2016-2020  Free Software Foundation, Inc.
 
 ;; Author: Eric Abrahamsen <eric@ericabrahamsen.net>
 
@@ -29,6 +29,25 @@
 (require 'rmailsum)
 (require 'mailheader)
 
+(defgroup ebdb-mua-rmail nil
+  "EBDB customization for rmail."
+  :group 'ebdb-mua)
+
+(defcustom ebdb-rmail-auto-update-p ebdb-mua-reader-update-p
+  "Rmail-specific value of `ebdb-mua-auto-update-p'."
+  :type '(choice (const :tag "do nothing" nil)
+                 (const :tag "search for existing records" existing)
+                 (const :tag "update existing records" update)
+                 (const :tag "query for update or record creation" query)
+                 (const :tag "update or create automatically" create)
+                 (function :tag "User-defined function")))
+
+(defcustom ebdb-rmail-window-size ebdb-default-window-size
+  "Size of the EBDB buffer when popping up in rmail.
+Size should be specified as a float between 0 and 1.  Defaults to
+the value of `ebdb-default-window-size'."
+  :type 'float)
+
 (defun ebdb/rmail-new-flag ()
   "Returns t if the current message in buffer BUF is new."
   (rmail-message-labels-p rmail-current-message ", ?\\(unseen\\),"))
@@ -57,13 +76,19 @@
 (cl-defmethod ebdb-make-buffer-name (&context (major-mode rmail-summary-mode))
   (format "*%s-Rmail*" ebdb-buffer-name))
 
+(cl-defmethod ebdb-popup-buffer (&context (major-mode rmail-summary-mode))
+  (list (get-buffer-window) ebdb-rmail-window-size))
+
 (defun ebdb-insinuate-rmail ()
   "Hook EBDB into RMAIL."
   (define-key rmail-mode-map ";" ebdb-mua-keymap))
 
+(defun ebdb-rmail-auto-update ()
+  (ebdb-mua-auto-update ebdb-rmail-auto-update-p))
+
 (add-hook 'rmail-mode-hook 'ebdb-insinuate-rmail)
 
-(add-hook 'rmail-show-message-hook 'ebdb-mua-auto-update)
+(add-hook 'rmail-show-message-hook 'ebdb-rmail-auto-update)
 
 (provide 'ebdb-rmail)
 ;;; ebdb-rmail.el ends here
